#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2015 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
PEAS gradebook view components.
"""

from zope.security.proxy import removeSecurityProxy

from z3c.form import field

from schooltool.course.interfaces import ISection
from schooltool.gradebook.browser.activity import IActivityForm
from schooltool.gradebook.browser.activity import FlourishActivityEditView
from schooltool.gradebook.browser.gradebook import ColumnPreferencesMenuOptions
from schooltool.gradebook.browser.gradebook import FlourishGradebookOverview
from schooltool.gradebook import GradebookMessage
from schooltool.requirement.interfaces import IEvaluations


class PeasColumnPreferencesMenuOptions(ColumnPreferencesMenuOptions):

    @property
    def columns(self):
        result = []
        if not self.view.deployed:
            result.append(('total', GradebookMessage('Total')))
            result.append(('average' , GradebookMessage('%')))
        return result


class PeasGradebookView(FlourishGradebookOverview):

    @property
    def show_absences_column(self):
        return False

    @property
    def show_tardies_column(self):
        return False


class PeasActivityEditView(FlourishActivityEditView):

    fields = field.Fields(IActivityForm)

    def update_scores(self, changed):
        worksheet = self.context.__parent__
        section = ISection(worksheet)
        for person in section.members.all():
            evaluations = IEvaluations(person)
            score = evaluations.get(self.context)
            if score is not None:
                scoreSystem = removeSecurityProxy(score.scoreSystem)
                for attr, value in changed.items():
                    setattr(scoreSystem, attr, value)

    def update_score_system(self, data):
        scoresystem = removeSecurityProxy(self.context.scoresystem)
        changed = {}
        if scoresystem.min != data['min']:
            scoresystem.min = data['min']
            changed['min'] = data['min']
        if scoresystem.max != data['max']:
            scoresystem.max = data['max']
            changed['max'] = data['max']
        if changed:
            self.update_scores(changed)

    def applyChanges(self, data):
        changes = super(PeasActivityEditView, self).applyChanges(data)
        self.update_score_system(data)
        return changes
