#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
PEAS person views.
"""

from datetime import date
from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile

from z3c.form import field

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.basicperson.browser.person import FlourishGeneralViewlet
from schooltool.basicperson.browser.person import FlourishPersonAddView
from schooltool.basicperson.browser.person import FlourishPersonEditView
from schooltool.basicperson.demographics import LEAVE_SCHOOL_FIELDS
from schooltool.basicperson.interfaces import IDemographicsFields
from schooltool.common import SchoolToolMessage
from schooltool.course.section import is_student

from schooltool.peas.demographics import ATTAINMENT_FIELDS


class PEASPersonAddView(object):

    def buildFieldsetGroups(self):
        relationship_fields = ['advisor']
        if not self.group_id:
            relationship_fields[0:0] = ['group']
        self.fieldset_groups = {
            'full_name': (
                SchoolToolMessage('Full Name'),
                ['last_name', 'middle_name', 'first_name']),
            'user': (
                SchoolToolMessage('User'),
                ['username', 'password', 'confirm']),
            'details': (
                SchoolToolMessage('Details'),
                ['gender', 'birth_date', 'photo']),
            'level': (
                SchoolToolMessage('Level'), ['level_date', 'level']),
            'group_date': (
                SchoolToolMessage('Enrollment Date'), ['group_date']),
            'demographics': (
                SchoolToolMessage('Demographics'), list(self.getDemoFields())),
            'relationships': (
                SchoolToolMessage('Relationships'), relationship_fields),
            }
        self.fieldset_order = (
            'full_name', 'details', 'demographics', 'level', 'group_date',
            'user')


class PEASPersonEditView(object):

    def buildFieldsetGroups(self):
        self.fieldset_groups = {
            'full_name': (
                SchoolToolMessage('Full Name'),
                ['last_name', 'middle_name', 'first_name']),
            'details': (
                SchoolToolMessage('Details'),
                ['gender', 'birth_date', 'photo']),
            'demographics': (
                SchoolToolMessage('Demographics'),
                list(self.generateExtraFields())),
            }
        self.fieldset_order = (
            'full_name', 'details', 'demographics')


class StudentAddView(PEASPersonAddView, FlourishPersonAddView):

    def getDemoFields(self):
        fields = field.Fields()
        dfs = IDemographicsFields(ISchoolToolApplication(None))
        keys = self.group_id and [self.group_id] or []
        for field_desc in dfs.filter_keys(keys):
            if field_desc.name not in LEAVE_SCHOOL_FIELDS:
                fields += field_desc.makeField()
        return fields


class TeacherAddView(PEASPersonAddView, FlourishPersonAddView):

    def buildFieldsetGroups(self):
        super(TeacherAddView, self).buildFieldsetGroups()
        self.fieldset_order = (
            'full_name', 'details', 'demographics', 'user')


class PersonEditView(PEASPersonEditView, FlourishPersonEditView):

    pass


class PEASGeneralViewlet(FlourishGeneralViewlet):

    template = ViewPageTemplateFile('templates/general_viewlet.pt')

    def update(self):
        self.attainment_widgets = []
        super(PEASGeneralViewlet, self).update()

    def is_student(self):
        return is_student(self.context)

    @property
    def filtered_widgets(self):
        result = []
        for widget in self.widgets.values():
            if widget.value:
                if widget.__name__ in ATTAINMENT_FIELDS:
                    self.attainment_widgets.append(widget)
                else:
                    result.append(widget)
        return result

    def makeRow(self, attr, value):
        if isinstance(value, date):
            value = value.strftime('%d/%m/%Y')
        return super(PEASGeneralViewlet, self).makeRow(attr, value)
