#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
PEAS skin customization.
"""

from zope.cachedescriptors.property import Lazy
from zope.i18n.interfaces.locales import ICollator
from z3c.form import converter
import zc.resourcelibrary

from schooltool.group.interfaces import IGroupContainer
from schooltool.group.group import defaultGroups
from schooltool.lyceum.journal.browser.journal import FlourishSchoolAttendanceGroupPicker
from schooltool.schoolyear.interfaces import ISchoolYear
from schooltool.skin import flourish


class CustomCSSViewlet(flourish.viewlet.Viewlet):

    def update(self):
        zc.resourcelibrary.need('schooltool.peas.custom')
        
    render = flourish.templates.Inline('''
      <link rel="stylesheet" type="text/css" href="layout.css" media="screen"
            tal:attributes="href context/++resource++schooltool.peas.custom/custom.css" />
    ''')


class GroupPicker(FlourishSchoolAttendanceGroupPicker):

    @Lazy
    def groups_by_year(self):
        result = []
        selected_group = self.view.group
        selected_key = None
        if self.view.group:
            selected_key = '%s.%s' % (
                ISchoolYear(selected_group.__parent__).__name__,
                selected_group.__name__)

        collator = ICollator(self.request.locale)
        for year in self.view.schoolyears:
            key = lambda g: '%s.%s' % (year.__name__, g.__name__)
            groups = sorted(IGroupContainer(year).values(),
                            key=lambda g: collator.key(g.title))
            result.append({
                'title': year.title,
                'groups': [
                    {'title': group.title,
                     'value': key(group),
                     'selected': key(group) == selected_key}
                    for group in groups
                    if group.__name__ not in defaultGroups],
                })
        return result


class PEASIntegerDataConverter(converter.IntegerDataConverter):

    def toWidgetValue(self, value):
        result = super(PEASIntegerDataConverter, self).toWidgetValue(value)
        if ',' in result:
            return result.replace(',', '')
        return result
