#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2015 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 10.

Hide default Sheet1 worksheets
"""

from zope.app.generations.utility import getRootFolder
from zope.component.hooks import getSite, setSite

from schooltool.course.interfaces import ISectionContainer
from schooltool.gradebook.interfaces import IActivities
from schooltool.schoolyear.interfaces import ISchoolYearContainer


def evolve(context):
    old_site = getSite()
    app = getRootFolder(context)
    setSite(app)
    schoolyears = ISchoolYearContainer(app)
    for schoolyear in schoolyears.values():
        for term in schoolyear.values():
            sections = ISectionContainer(term)
            for section in sections.values():
                worksheets = IActivities(section)
                worksheet = worksheets.get('Worksheet')
                if worksheet is not None:
                    worksheet.hidden = True
                    worksheet.deployed = True
    setSite(old_site)
