#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 2.

Updates address demographics fields.
"""

from zope.app.generations.utility import getRootFolder

from schooltool.basicperson.interfaces import IDemographicsFields
from schooltool.basicperson.demographics import DescriptionFieldDescription
from schooltool.basicperson.demographics import TextFieldDescription


def evolve(context):
    app = getRootFolder(context)
    dfs = IDemographicsFields(app)
    order = [k for k in dfs]
    fields = ['address_district', 'address_subcounty', 'address_parish']
    changed = False
    for field_name in fields:
        if field_name in dfs:
            field = dfs[field_name]
            if isinstance(field, DescriptionFieldDescription):
                name = field.name
                title = field.title
                limit_keys = field.limit_keys[:]
                del dfs[field_name]
                dfs[field_name] = TextFieldDescription(
                    name, title, limit_keys=limit_keys)
                changed = True
    if changed:
        dfs.updateOrder(order)
