#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 5.

Changed activity labels in Target sheet
"""

from zope.app.generations.utility import findObjectsProviding
from zope.app.publication.zopepublication import ZopePublication
from zope.component.hooks import getSite, setSite

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.schoolyear.interfaces import ISchoolYearContainer
from schooltool.term.interfaces import ITermContainer
from schooltool.course.interfaces import ISectionContainer
from schooltool.gradebook.interfaces import IActivities

from schooltool.peas.assessment import TARGET_SHEET_ID


def evolve(context):
    root = context.connection.root().get(ZopePublication.root_name, None)

    old_site = getSite()
    apps = list(findObjectsProviding(root, ISchoolToolApplication))
    for app in apps:
        setSite(app)
        schoolyears = ISchoolYearContainer(app)
        for schoolyear in schoolyears.values():
            terms = ITermContainer(schoolyear)
            for term in terms.values():
                sections = ISectionContainer(term)
                for section in sections.values():
                    activities = IActivities(section)
                    target = activities.get(TARGET_SHEET_ID)
                    if target is not None:
                        # discrete activity
                        activity = target.get(TARGET_SHEET_ID)
                        if activity is not None:
                            activity.label = u'1-9'
                        # ranged activity
                        activity = target.get(TARGET_SHEET_ID+'-ranged')
                        if activity is not None:
                            activity.label = u'%'
    setSite(old_site)
