#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Evolve database to generation 7.

Add out of school and reason to student demographics fields
"""

from zope.app.generations.utility import getRootFolder

from schooltool.basicperson.interfaces import IDemographicsFields
from schooltool.basicperson.demographics import BoolFieldDescription
from schooltool.basicperson.demographics import EnumFieldDescription
from schooltool.peas import PeasMessage as _


def evolve(context):
    app = getRootFolder(context)
    dfs = IDemographicsFields(app)
    if 'out_of_school' not in dfs:
        dfs['out_of_school'] = BoolFieldDescription(
            'out_of_school',
            _('Out of school for more than 1 year before coming to PEAS?'),
            limit_keys=['students'])
        order = dfs.keys()
        order.pop()
        order.insert(order.index('language'), 'out_of_school')
        dfs.updateOrder(list(order))
    if 'out_of_school_reason' not in dfs:
        dfs['out_of_school_reason'] = EnumFieldDescription(
            'out_of_school_reason', _('Reason for being out of school?'),
            limit_keys=['students'])
        dfs['out_of_school_reason'].items = [
            _('Left to have a baby (pregnancy)'),
            _('Work'),
            _('Family death or illness'),
            _('Fees'),
            _('Other')]
        order = dfs.keys()
        order.pop()
        order.insert(order.index('language'), 'out_of_school_reason')
        dfs.updateOrder(list(order))
